################
Sector Coupling
################


This section provides examples related to coupling different energy sectors in a power system optimization:


.. toctree::
    :maxdepth: 1

    ../examples/sector-coupling-single-node.ipynb
    ../examples/battery-electric-vehicle-charging.ipynb
    ../examples/biomass-synthetic-fuels-carbon-management.ipynb
    ../examples/chp-fixed-heat-power-ratio.ipynb
    ../examples/lopf-with-heating.ipynb
    ../examples/power-to-gas-boiler-chp.ipynb
    ../examples/power-to-heat-water-tank.ipynb
